@@ -34,6 +34,13 @@ func TestDefaultResolver_Resolve(t *testing.T) {
 		},
 	}
 
+	composeSecrets := func(file bool) Secrets {
+		secret := secrets[variableKey]
+		secret.File = &file
+
+		return Secrets{variableKey: secret}
+	}
+
 	getLogger := func(t *testing.T) (logger, func()) {
 		logger := new(mockLogger)
 		logger.On("Println", mock.Anything).Maybe()
@@ -72,7 +79,7 @@ func TestDefaultResolver_Resolve(t *testing.T) {
 			expectedVariables:        nil,
 			expectedError:            assert.AnError,
 		},
-		"secret resolved properly": {
+		"secret resolved properly - file not defined": {
 			getLogger:                getLogger,
 			supportedResolverPresent: true,
 			secrets:                  secrets,
@@ -85,6 +92,32 @@ func TestDefaultResolver_Resolve(t *testing.T) {
 			},
 			expectedError: nil,
 		},
+		"secret resolved properly - file set to true": {
+			getLogger:                getLogger,
+			supportedResolverPresent: true,
+			secrets:                  composeSecrets(true),
+			expectedVariables: JobVariables{
+				{
+					Key:   variableKey,
+					Value: returnValue,
+					File:  true,
+				},
+			},
+			expectedError: nil,
+		},
+		"secret resolved properly - file set to false": {
+			getLogger:                getLogger,
+			supportedResolverPresent: true,
+			secrets:                  composeSecrets(false),
+			expectedVariables: JobVariables{
+				{
+					Key:   variableKey,
+					Value: returnValue,
+					File:  false,
+				},
+			},
+			expectedError: nil,
+		},
 		"no supported resolvers present": {
 			getLogger: func(t *testing.T) (logger, func()) {
 				logger := new(mockLogger)
