@@ -1,9 +1,10 @@
+// +build !integration
+
 package docker
 
 import (
 	"context"
 	"errors"
-	"flag"
 	"fmt"
 	"io/ioutil"
 	"os"
@@ -38,13 +39,6 @@ import (
 	"gitlab.com/gitlab-org/gitlab-runner/shells"
 )
 
-func TestMain(m *testing.M) {
-	PrebuiltImagesPaths = []string{"../../out/helper-images/"}
-
-	flag.Parse()
-	os.Exit(m.Run())
-}
-
 func TestParseDeviceStringOne(t *testing.T) {
 	e := new(executor)
 
@@ -1710,7 +1704,7 @@ func TestHelperImageRegistry(t *testing.T) {
 		// logic and leaking abstractions.
 		expectedHelperImageName string
 	}{
-		"Docker Hub helper image": {
+		"Default helper image": {
 			build: &common.Build{
 				JobResponse: common.JobResponse{
 					Image: common.Image{
@@ -1723,9 +1717,9 @@ func TestHelperImageRegistry(t *testing.T) {
 					},
 				},
 			},
-			expectedHelperImageName: helperimage.DockerHubName,
+			expectedHelperImageName: helperimage.GitLabRegistryName,
 		},
-		"GitLab Registry helper image": {
+		"DockerHub helper image": {
 			build: &common.Build{
 				JobResponse: common.JobResponse{
 					Image: common.Image{
@@ -1734,7 +1728,7 @@ func TestHelperImageRegistry(t *testing.T) {
 					Variables: common.JobVariables{
 						common.JobVariable{
 							Key:      featureflags.GitLabRegistryHelperImage,
-							Value:    "true",
+							Value:    "false",
 							Public:   false,
 							Internal: false,
 							File:     false,
@@ -1749,7 +1743,7 @@ func TestHelperImageRegistry(t *testing.T) {
 					},
 				},
 			},
-			expectedHelperImageName: helperimage.GitLabRegistryName,
+			expectedHelperImageName: helperimage.DockerHubName,
 		},
 		"helper image overridden still use default helper image in prepare": {
 			build: &common.Build{
@@ -1768,15 +1762,15 @@ func TestHelperImageRegistry(t *testing.T) {
 			},
 			// We expect the default image to still be chosen since the check of
 			// the override happens at a later stage.
-			expectedHelperImageName: helperimage.DockerHubName,
+			expectedHelperImageName: helperimage.GitLabRegistryName,
 		},
-		"helper image overridden still use registry.gitlab.com helper image in prepare": {
+		"helper image overridden still use DockerHub helper image in prepare": {
 			build: &common.Build{
 				JobResponse: common.JobResponse{
 					Variables: common.JobVariables{
 						common.JobVariable{
 							Key:   featureflags.GitLabRegistryHelperImage,
-							Value: "true",
+							Value: "false",
 						},
 					},
 					Image: common.Image{
@@ -1791,9 +1785,9 @@ func TestHelperImageRegistry(t *testing.T) {
 					},
 				},
 			},
-			// We expect the registry.gitlab.com image to still be chosen since
+			// We expect the DockerHub image to still be chosen since
 			// the check of the override happens at a later stage.
-			expectedHelperImageName: helperimage.GitLabRegistryName,
+			expectedHelperImageName: helperimage.DockerHubName,
 		},
 	}
 
@@ -1852,6 +1846,7 @@ func TestLocalHelperImage(t *testing.T) {
 	tests := map[string]struct {
 		jobVariables     common.JobVariables
 		helperImageInfo  helperimage.Info
+		imageFlavor      string
 		shell            string
 		clientAssertions func(*docker.MockClient)
 		expectedImage    *types.ImageInspect
@@ -1953,34 +1948,6 @@ func TestLocalHelperImage(t *testing.T) {
 			},
 			expectedImage: &types.ImageInspect{},
 		},
-		"entrypoint not added when feature flag turned off": {
-			jobVariables: common.JobVariables{
-				common.JobVariable{
-					Key:   featureflags.ResetHelperImageEntrypoint,
-					Value: "false",
-				},
-			},
-			helperImageInfo: defaultHelperImageInfo,
-			clientAssertions: func(c *docker.MockClient) {
-				c.On(
-					"ImageImportBlocking",
-					mock.Anything,
-					mock.Anything,
-					mock.Anything,
-					types.ImageImportOptions{
-						Tag:     "localimageimport",
-						Changes: nil,
-					},
-				).Return(nil)
-
-				c.On(
-					"ImageInspectWithRaw",
-					mock.Anything,
-					mock.Anything,
-				).Return(types.ImageInspect{}, []byte{}, nil)
-			},
-			expectedImage: &types.ImageInspect{},
-		},
 		"nil is returned if error on import": {
 			helperImageInfo: defaultHelperImageInfo,
 			clientAssertions: func(c *docker.MockClient) {
@@ -2024,7 +1991,45 @@ func TestLocalHelperImage(t *testing.T) {
 						return assert.IsType(t, new(os.File), source.Source) &&
 							assert.Equal(
 								t,
-								"prebuilt-x86_64-pwsh.tar.xz",
+								"prebuilt-alpine-x86_64-pwsh.tar.xz",
+								path.Base((source.Source.(*os.File)).Name()),
+							)
+					}),
+					helperimage.DockerHubName,
+					mock.Anything,
+				).Return(nil)
+
+				imageInspect := types.ImageInspect{
+					RepoTags: []string{
+						dockerHubHelperImage,
+					},
+				}
+
+				c.On(
+					"ImageInspectWithRaw",
+					mock.Anything,
+					dockerHubHelperImage,
+				).Return(imageInspect, []byte{}, nil)
+			},
+			expectedImage: &types.ImageInspect{
+				RepoTags: []string{
+					dockerHubHelperImage,
+				},
+			},
+		},
+		"Powershell image is used when shell is pwsh and flavor ubuntu": {
+			helperImageInfo: defaultHelperImageInfo,
+			imageFlavor:     "ubuntu",
+			shell:           shells.SNPwsh,
+			clientAssertions: func(c *docker.MockClient) {
+				c.On(
+					"ImageImportBlocking",
+					mock.Anything,
+					mock.MatchedBy(func(source types.ImageImportSource) bool {
+						return assert.IsType(t, new(os.File), source.Source) &&
+							assert.Equal(
+								t,
+								"prebuilt-ubuntu-x86_64-pwsh.tar.xz",
 								path.Base((source.Source.(*os.File)).Name()),
 							)
 					}),
@@ -2069,6 +2074,9 @@ func TestLocalHelperImage(t *testing.T) {
 					Config: common.RunnerConfig{
 						RunnerSettings: common.RunnerSettings{
 							Shell: tt.shell,
+							Docker: &common.DockerConfig{
+								HelperImageFlavor: tt.imageFlavor,
+							},
 						},
 					},
 				},
@@ -2093,8 +2101,10 @@ func createFakePrebuiltImages(t *testing.T, architecture string) func() {
 	prevPrebuiltImagesPaths := PrebuiltImagesPaths
 	PrebuiltImagesPaths = []string{tempImgDir}
 	for _, fakeImgName := range []string{
-		fmt.Sprintf("prebuilt-%s.tar.xz", architecture),
-		fmt.Sprintf("prebuilt-%s-pwsh.tar.xz", architecture),
+		fmt.Sprintf("prebuilt-alpine-%s.tar.xz", architecture),
+		fmt.Sprintf("prebuilt-alpine-%s-pwsh.tar.xz", architecture),
+		fmt.Sprintf("prebuilt-ubuntu-%s.tar.xz", architecture),
+		fmt.Sprintf("prebuilt-ubuntu-%s-pwsh.tar.xz", architecture),
 	} {
 		fakeLocalImage, err := os.Create(path.Join(tempImgDir, fakeImgName))
 		require.NoError(t, err)
