@@ -69,13 +69,15 @@ func (d *machinesData) writeDebugInformation() {
 	if err != nil {
 		return
 	}
-	defer file.Close()
-	fmt.Fprintln(file,
+	defer func() { _ = file.Close() }()
+	_, _ = fmt.Fprintln(
+		file,
 		"time", time.Now(),
 		"runner", d.Runner,
 		"acquired", d.Acquired,
 		"creating", d.Creating,
 		"idle", d.Idle,
 		"used", d.Used,
-		"removing", d.Removing)
+		"removing", d.Removing,
+	)
 }
