@@ -29,6 +29,11 @@ func TestVersion(t *testing.T) {
 			expectedVersion: V2004,
 			expectedErr:     nil,
 		},
+		{
+			operatingSystem: "Windows Server Datacenter Version 2009 (OS Build 19042.985)",
+			expectedVersion: V20H2,
+			expectedErr:     nil,
+		},
 		{
 			operatingSystem: "some random string",
 			expectedErr:     NewUnsupportedWindowsVersionError("some random string"),
