@@ -126,12 +126,12 @@ var flags = []FeatureFlag{
 	},
 	{
 		Name:            SkipDockerMachineProvisionOnCreationFailure,
-		DefaultValue:    false,
+		DefaultValue:    true,
 		Deprecated:      false,
 		ToBeRemovedWith: "",
 		Description: "With the `docker+machine` executor, when a machine is " +
 			"not created, `docker-machine provision` runs for X amount of times. When " +
-			"this feature flag is set to `true`, it skips `docker-machine provision` " +
+			"this feature flag is set to `true`, it skips `docker-machine provision`, " +
 			"removes the machine, and creates another machine instead.",
 	},
 	{
