@@ -30,17 +30,17 @@ type Buffer struct {
 	checksum hash.Hash32
 }
 
-type lengthSort []string
+type inverseLengthSort []string
 
-func (s lengthSort) Len() int {
+func (s inverseLengthSort) Len() int {
 	return len(s)
 }
 
-func (s lengthSort) Swap(i, j int) {
+func (s inverseLengthSort) Swap(i, j int) {
 	s[i], s[j] = s[j], s[i]
 }
 
-func (s lengthSort) Less(i, j int) bool {
+func (s inverseLengthSort) Less(i, j int) bool {
 	return len(s[i]) > len(s[j])
 }
 
@@ -59,8 +59,14 @@ func (b *Buffer) SetMasked(values []string) {
 
 	transformers := make([]transform.Transformer, 0, len(values)+len(defaultTransformers))
 
-	sort.Sort(lengthSort(values))
+	sort.Sort(inverseLengthSort(values))
+	seen := make(map[string]struct{})
 	for _, value := range values {
+		if _, ok := seen[value]; ok {
+			continue
+		}
+		seen[value] = struct{}{}
+
 		transformers = append(transformers, newPhraseTransform(value))
 	}
 
@@ -94,14 +100,33 @@ func (b *Buffer) Write(p []byte) (int, error) {
 	b.lock.Lock()
 	defer b.lock.Unlock()
 
-	n, err := b.w.Write(p)
-	// if we get a log limit exceeded error, we've written the log limit
-	// notice out to the log and will now silently not write any additional
-	// data: we return len(p), nil so the caller continues as normal.
-	if err == errLogLimitExceeded {
-		return len(p), nil
+	src := p
+	var n int
+	for len(src) > 0 {
+		written, err := b.w.Write(src)
+		// if we get a log limit exceeded error, we've written the log limit
+		// notice out to the log and will now silently not write any additional
+		// data: we return len(p), nil so the caller continues as normal.
+		if err == errLogLimitExceeded {
+			return len(p), nil
+		}
+		if err != nil {
+			return n, err
+		}
+
+		// the text/transformer implementation can return n < len(p) without an
+		// error. For this reason, we continue writing whatever data is left
+		// unless nothing was written (therefore zero progress) on our call to
+		// Write().
+		if written == 0 {
+			return n, io.ErrShortWrite
+		}
+
+		src = src[written:]
+		n += written
 	}
-	return n, err
+
+	return n, nil
 }
 
 func (b *Buffer) Finish() {
