@@ -1,3 +1,5 @@
+// +build !integration
+
 package referees
 
 import (
@@ -5,26 +7,39 @@ import (
 
 	"github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/mock"
 )
 
 func Test_CreateReferees(t *testing.T) {
+	fakeMockMetricsExecutor := func(t *testing.T) (interface{}, func(t mock.TestingT) bool) {
+		return struct{}{}, func(t mock.TestingT) bool { return false }
+	}
+
+	mockMetricsExecutor := func(t *testing.T) (interface{}, func(t mock.TestingT) bool) {
+		m := new(MockMetricsExecutor)
+
+		m.On("GetMetricsSelector").Return(`name="value"`).Maybe()
+
+		return m, m.AssertExpectations
+	}
+
 	testCases := map[string]struct {
-		executor         interface{}
+		mockExecutor     func(t *testing.T) (interface{}, func(t mock.TestingT) bool)
 		config           *Config
 		expectedReferees []Referee
 	}{
 		"Executor doesn't support any referee": {
-			executor:         new(mockExecutor),
+			mockExecutor:     fakeMockMetricsExecutor,
 			config:           &Config{Metrics: &MetricsRefereeConfig{QueryInterval: 0}},
 			expectedReferees: nil,
 		},
 		"Executor supports metrics referee": {
-			executor:         new(mockMetricsExecutor),
+			mockExecutor:     mockMetricsExecutor,
 			config:           &Config{Metrics: &MetricsRefereeConfig{QueryInterval: 0}},
 			expectedReferees: []Referee{&MetricsReferee{}},
 		},
 		"No config provided": {
-			executor:         new(mockMetricsExecutor),
+			mockExecutor:     mockMetricsExecutor,
 			config:           nil,
 			expectedReferees: nil,
 		},
@@ -34,7 +49,10 @@ func Test_CreateReferees(t *testing.T) {
 		t.Run(testName, func(t *testing.T) {
 			logger := logrus.WithField("test", t.Name())
 
-			referees := CreateReferees(test.executor, test.config, logger)
+			executor, assertExpectations := test.mockExecutor(t)
+			defer assertExpectations(t)
+
+			referees := CreateReferees(executor, test.config, logger)
 
 			if test.expectedReferees == nil {
 				assert.Nil(t, referees)
